use nxui::messagebox::MessageBox;
use nxui::window::Frame;
use nxui::natives_and_messaging::*;

fn main() {
    nxui::initialize();
    MessageBox::new("日本語ｷﾀーーー！！ ", "日本語が使えるようになりました。", DS_QUESTION, BS_YESNO).show(Frame::default());
}